/*
Teeny Win32 demo program.

Orion Sky Lawlor, olawlor@acm.org, 2006/04/18 (Public Domain)
*/
#undef UNICODE /* Use ASCII versions of Windows calls, not Unicode */
#define _CRT_SECURE_NO_DEPRECATE 1 /* don't whine about fopen, man... */

#include <windows.h> //<- main windows header
#include <string.h>

/* Windows libraries.  Should be listed on the command line, but just in case... */
#pragma comment (lib, "kernel32.lib") 
#pragma comment (lib, "user32.lib") 
#pragma comment (lib, "gdi32.lib") 


/* Function Prototypes */
LRESULT CALLBACK myWndProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam);
LRESULT CALLBACK myAboutBox(HWND hDlg, UINT message, WPARAM wParam, LPARAM lParam);
void windowRepaint(void);
void handleMouse(int x,int y,int keys,UINT msg);

/************** Globals **********/
const char *WindowClass_name="myWndproc1_0";
HINSTANCE hInst; // current application instance
HWND hWnd; //Window handle

/********************** Actual Code Starts Here **************************/

/* Main program */
int APIENTRY WinMain(HINSTANCE hInst_,
                     HINSTANCE hPrevInstance,
                     LPSTR     lpCmdLine, /* command-line args */
                     int       nCmdShow)
{
	hInst=hInst_;

	//Register our new "window class" so we can handle events.
	WNDCLASSEX wcex;
	memset(&wcex,0,sizeof(wcex)); /* Set everything unused to zero */
	wcex.cbSize = sizeof(wcex); 
	wcex.lpfnWndProc	= (WNDPROC)myWndProc; /* procedure to call with events */
	wcex.lpszClassName	= WindowClass_name;
	wcex.style			= CS_HREDRAW | CS_VREDRAW;
	wcex.hCursor		= LoadCursor(NULL, IDC_ARROW); /* prevents hourglass at startup */
	RegisterClassEx(&wcex);

	// Create a window of that class
	hWnd = CreateWindow(WindowClass_name, 
			"- Blackscreen -", 
			WS_OVERLAPPEDWINDOW,
			CW_USEDEFAULT, 0, CW_USEDEFAULT, 0, NULL, NULL, hInst, NULL);
	//LONG style=GetWindowLong(hWnd,GWL_STYLE);
	//SetWindowLong(hWnd,GWL_STYLE, style & ~WS_CAPTION);
	
	ShowWindow(hWnd,nCmdShow); // <- windows start invisible, so must show them...

	// Handle events
	MSG msg;
	while (1==GetMessage(&msg, hWnd, 0, 0)) {
			TranslateMessage(&msg);
			DispatchMessage(&msg); /* calls myWndProc, which calls classWndProc */
	}
	return 0;
}

// "Window Procedure": the main place events get handled
LRESULT CALLBACK myWndProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
{
	switch (message) 
	{
/*Keyboard*/
	case WM_CHAR: case WM_SYSCHAR:
		if (LOWORD(wParam)=='q') exit(0);
		break;
/*Window*/
	case WM_ERASEBKGND:
		/*Just ignore this, which prevents flashing on redraws*/
		return 1;
	case WM_PAINT: /* have to draw stuff inside window from scratch */
		windowRepaint();
		return 0;
	case WM_CLOSE: //Asked to close window
		exit(0); /* Just exit normally */
		return 0;
	default:
		//WT1("                      (unknown 0x%04x)",message)
		break;
	}
	/* Pass everything not handled yet on to the default window handling */
	return DefWindowProc(hWnd, message, wParam, lParam);
}

/* Called to draw window from scratch */
void windowRepaint(void) 
{
	/* Every redraw has to be wrapped in BeginPaint/EndPaint, or
	else Windows doesn't think it actually happened... */
	PAINTSTRUCT ps;
	HDC hdc=BeginPaint(hWnd, &ps);

	/* Clear the interior of the window */
	RECT rt;
	GetClientRect(hWnd, &rt);
	FillRect(hdc, &rt, (HBRUSH)GetStockObject(BLACK_BRUSH));

	EndPaint(hWnd, &ps);
}
